@@ -1,13 +1,14 @@
-from base64 import b64decode
-
 from django.contrib.auth.models import Group, User
 from django.db import models
 
+from django_simple_aes_field.fields import AESField
+
+
 class Password(models.Model):
     name = models.CharField(max_length=255)
     username = models.CharField(max_length=255, null=True, blank=True)
     domain = models.CharField(max_length=255, null=True, blank=True)
-    passwd = models.CharField(max_length=255)
+    passwd = AESField()
     user = models.ForeignKey(User, related_name='user_related')
     group = models.ManyToManyField(Group, blank=True, help_text='Deselect all groups to make password private.')
 
@@ -23,15 +24,11 @@ class Password(models.Model):
     def __unicode__(self):
         return self.name
 
-    @property
-    def password(self):
-        return b64decode(self.passwd)
-
     def is_public(obj):
         if obj.group.count() > 0:
             return True
-        else:
-            return False
+        return False
+
     is_public.short_description = 'Public?'
     is_public.boolean = True
 
